/* ***************************************************************************
   *                                                                         *
   *   Kindermann                                   WPK-Produktentwicklung   *
   *                                                Schuljahr 2016/17        *
   *                           WiFiSchalter 1                                *
   *                          für das ESP01-Board                            *
   *                                                                         *
   *                                                                         *
   ***************************************************************************/



#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>
#include <WiFiManager.h>
#include <Ticker.h>

Ticker ticker;

ESP8266WebServer server(80);
MDNSResponder mdns;


String webPage1 = "", webPage2 = "";

int gpio0Led = 0;
int gpio2Led = 2;

unsigned long ledstatus = 0;

void tick()
{
  //Toggle Status
  int state = digitalRead(gpio0Led);
  digitalWrite(gpio0Led, !state);
}

void configModeCallback (WiFiManager *myWiFiManager) {
  //Konfigurationsmodus -> LED blinkt schneller
  ticker.attach(0.2, tick);
}

void setup(void){
   
  webPage1 += "<!DOCTYPE html><HTML>\r\n";
  webPage1 += "<HEAD>\r\n";
  webPage1 += "<META content=\"text/html; ";
  webPage1 += "charset=\"ISO-8859-1\"; ";
  webPage1 += "http-equiv=\"content-type\">\r\n";
  webPage1 += "<TITLE>WiFiSchalter</TITLE>\r\n";
  webPage1 += "</HEAD>\r\n";
  webPage1 += "<BODY><CENTER>\r\n";
  webPage1 += "<FONT face=Verdana>\r\n";
  webPage1 += "<H1>WiFiSchalter</H1>\r\n";
  webPage1 += "LED-Status: ";
  webPage2 += "<br>\r\n<br>\r\n";
  webPage2 += "<table cellpadding=\"10\" cellspacing=\"0\" border=\"0\">\r\n";
  webPage2 += "<tr><td align=left><button style=height:25px;width:60px onclick=location.href=\"on\" \"";
  webPage2 += "type=button>EIN</button></td><td align=left>LED einschalten</td></tr>\r\n";
  webPage2 += "<tr><td align=left><button style=height:25px;width:60px onclick=location.href=\"off\" \"";
  webPage2 += "type=button>AUS</button></td><td align=left>LED ausschalten</td></tr>\r\n";
  webPage2 += "</table>\r\n";
  webPage2 += "<BODY>\r\n";
  webPage2 += "<FONT SIZE=-2>(c) Dietrich Kindermann 2017<br></CENTER></BODY></HTML>";
    
  // GPIOs konfigurieren
  pinMode(gpio0Led, OUTPUT);
  digitalWrite(gpio0Led, HIGH);

  pinMode(gpio2Led, OUTPUT);
  digitalWrite(gpio2Led, HIGH);
 
  // Ticker starten ...
  ticker.attach(0.6, tick);
  
  WiFiManager wifiManager;
  
  delay(2000);
 
  // überprüfen, ob Tx und Rx gebrückt sind ...
  pinMode(1, OUTPUT);       // TX
  pinMode(3, INPUT_PULLUP); // Rx
  digitalWrite(1, 1);
  delayMicroseconds(2);
  if (!digitalRead(3))goto weiter;

  digitalWrite(1, 0);
  delayMicroseconds(2);
  if (digitalRead(3))goto weiter;
  wifiManager.resetSettings();
  weiter:


  WiFi.hostname("WiFiSchalter");
  
  //Access Point Modus
  wifiManager.setAPCallback(configModeCallback);

  //SSID und Passwort laden und einloggen ...
  if (!wifiManager.autoConnect()) {
    ESP.reset();
    delay(1000);
  }

  //if you get here you have connected to the WiFi
  ticker.detach();
  //keep LED on
  digitalWrite(gpio0Led, LOW);
  digitalWrite(1, HIGH);
     
  mdns.begin("esp8266", WiFi.localIP());
  
  server.on("/", [](){
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
  });
  server.on("/on", [](){
    ledstatus=1;
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
    digitalWrite(gpio2Led, LOW); 
    delay(1000);
  });
  server.on("/off", [](){
    ledstatus=0;
    server.send(200, "text/html", webPage1 + ledstatus + webPage2);
    digitalWrite(gpio2Led, HIGH);
     delay(1000); 
  });
  server.begin();  
}
 
void loop(void){
  server.handleClient();
} 


